@@ -25,54 +25,54 @@
 function(data, digits=6, version=3) {
 
 	if (version!=3) {
-		warning("older versions of fingerprints are not recommended, current is version 3");
+		warning("older versions of fingerprints are not recommended, current is version 3")
 	} 
 	if (is.vector(data)) {
 		len = 1
 	} else if (is.data.frame(data)) {
-		len = length(data);
+		len = length(data)
 	} else {
-		warning("forcing to data frame");
-		data=as.data.frame(data);
-		len = length(data);
+		warning("forcing to data frame")
+		data=as.data.frame(data)
+		len = length(data)
 	}
 
 	if (len==0) {
-		warning ("NULL data");
-		return(NULL);
+		warning ("NULL data")
+		return(NULL)
 	}
 	if (is.factor(data)) {
-		data = as.character(data);
+		data = as.character(data)
 	}
 
-	r = vector(mode="list", length=len);
+	r = vector(mode="list", length=len)
 	if (is.vector(data)) {
-		r[[1]] =  unfV(data,digits,version);
+		r[[1]] =  unfV(data,digits,version)
 	} else {
 		for ( i in 1:len) {
-			r[[i]] =  unfV(data[[i]],digits,version);
+			r[[i]] =  unfV(data[[i]],digits,version)
         	}
 	}
 
-	class(r)="unf";
-	return(r);
+	class(r)="unf"
+	return(r)
 }
 
 summary.unf<-function(object,...) {
 	if (length(object)==1) {
-		#return(attr(object[[1]],"base64"));
-		return(object);
+		#return(attr(object[[1]],"base64"))
+		return(object)
 	} 
 		
 	sigs = as.character(sapply(object,attributes)["base64",])
-	return(unf(sigs));
+	return(unf(sigs))
 	#return(attr(unf(sigs,32,3)[[1]],"base64"));	
 }
 
 
 "unfV" <-
 function(v, digits=6, version=3) {
-	INITSTRING = sprintf("%0.20i",as.integer(0));
+	INITSTRING = sprintf("%0.20i",as.integer(0))
 
 	if (version == 1) {
 		if (is.character(v)) {
@@ -82,14 +82,14 @@ function(v, digits=6, version=3) {
 			as.integer(length(v)), as.integer(digits), 
 			fingerprint =double(length=1),
 			base64= INITSTRING 
-			);
+			)
 		} else {
 		    r = .C("R_unf1_double", NAOK=TRUE, as.double(v), as.integer(length(v)),
 			PACKAGE="UNF", 
 			as.integer(digits), 
 			fingerprint=double(length=1),
 			base64= INITSTRING 
-			);
+			)
 		}
 	} else if (version == 2) {
 		if (is.character(v)) {
@@ -99,18 +99,18 @@ function(v, digits=6, version=3) {
 			as.integer(length(v)), as.integer(digits), 
 			fingerprint =double(length=1),
 			base64= INITSTRING 
-			);
+			)
 		} else {
 		    r = .C("R_unf2_double", as.double(v), as.integer(length(v)),
 			PACKAGE="UNF", 
 			as.integer(digits), NAOK=TRUE,
 			fingerprint=double(length=1),
 			base64= INITSTRING 
-			);
+			)
 		}
 	} else {
 		if (version!=3)  {
-			warning("unsupported fingerprint version, using version 3");
+			warning("unsupported fingerprint version, using version 3")
 		}
 		if (is.character(v)) {
 		   r = .C("R_unf3_char",  NAOK=TRUE,
@@ -119,69 +119,69 @@ function(v, digits=6, version=3) {
 			 as.integer(length(v)), as.integer(digits), 
 			fingerprint =integer(length=16),
 			base64= INITSTRING 
-			);
+			)
 		} else {
 		   r = .C("R_unf3_double", PACKAGE="UNF", 
 			NAOK=TRUE, as.double(v), as.integer(length(v)),
 			as.integer(digits), 
 			fingerprint =integer(length=16),
 			base64= INITSTRING
-			);
+			)
 		}
 	} 
 	
 	sig = r$base64;	
-	class(sig)="unfV";
-	attr(sig,"digits")=digits;
-	attr(sig,"version")=version;
-	attr(sig,"isnested")=FALSE;
-	attr(sig,"base64")=r$base64;
-	attr(sig,"fingerprint")=r$fingerprint;
-	return(sig);
+	class(sig)="unfV"
+	attr(sig,"digits")=digits
+	attr(sig,"version")=version
+	attr(sig,"isnested")=FALSE
+	attr(sig,"base64")=r$base64
+	attr(sig,"fingerprint")=r$fingerprint
+	return(sig)
 }
 
 print.unf<-function(x,...) {
 	for (i in 1:length(x)) {
 	   print (paste("UNF",attr(x[[i]],"version"), attr(x[[i]],"digits"),
 		attr(x[[i]],"base64")
-		 ,sep=":") ) ;
+		 ,sep=":") ) 
 	}
 }
 
 "unfTest" <-
 function(silent=TRUE) {
-	ret = TRUE;
+	ret = TRUE
 
    x1 = 1:20
    x2 = x1 +.00001
 
    if (as.character(unf(x1))==as.character(unf(x2))) {
-	ret=FALSE;
+	ret=FALSE
 	if (!silent) {
-		warning("Failed discrimination test.");
+		warning("Failed discrimination test.")
         }
    }
    if (as.character(unf(x1,digits=5))!=as.character(unf(x2,digits=5))) {
-	ret=FALSE;
+	ret=FALSE
 	if (!silent) {
-		warning("Failed significance test 1.");
+		warning("Failed significance test 1.")
         }
    }
    if (as.character(unf(x1))!=as.character(unf(x2,digits=5))) {
-	ret=FALSE;
+	ret=FALSE
 	if (!silent) {
-		warning("Failed significance test 2.");
+		warning("Failed significance test 2.")
         }
    }
 	
-   cv = c(29,20,166,62,47,80,103,57,72,3,226,176,152,51,79,243);
+   cv = c(29,20,166,62,47,80,103,57,72,3,226,176,152,51,79,243)
   if (sum(attr(unf(x1)[[1]],"fingerprint")!=cv)>0) {
-	ret=FALSE;
+	ret=FALSE
 	if (!silent) {
-		warning("Failed replication.");
+		warning("Failed replication.")
        }
   }
 
 
-   return(ret);
+   return(ret)
 }
